/*
 * IBM Confidential
 * OCO Source Materials
 * Rational ClearCase
 * (C) Copyright IBM Corp. 2013.  All rights reserved.
 *
 * The source code for this program is not published or otherwise
 * divested of its trade secrets, irrespective of what has been
 * deposited with the U.S. Copyright Office.
 */

package com.ibm.rational.wvcm.stp.cc;

/**
 * Policies associated with a UCM project and its corresponding 
 * UCM Stream(s).  
 * For more information, see the cleartool man page "mkproject".
 */

public enum CcUcmPolicy {
    
    /**
     * Recommend snapshot views for integration work.
     */
    UNIX_INT_SNAP,
    WIN_INT_SNAP,
    
    /**
     * Recommend snapshot views for development work.
     * Not applicable for single stream development
     */
    UNIX_DEV_SNAP,    
    WIN_DEV_SNAP,
    
    /**
     * Skip permission checking to allow any user
     * to modify an existing project.
     */
    CHPROJECT_UNRESTRICTED,
    
    /**
     * Skip permission checking to allow any user
     * to modify an existing stream.     
     */
    CHSTREAM_UNRESTRICTED,
    
    /**
     * Require a development stream to be based on
     * current recommended baselines before 
     * it can deliver changes to its default target stream.
     * Not applicable for single stream development
     */
    DELIVER_REQUIRE_REBASE,
    
    /**
     * Do not allow delivery from a development stream 
     * that has checkouts.
     * Not applicable for single stream development
     */
    DELIVER_NCO_DEVSTR,
    
    /**
     * Allows delivery of activities that have no 
     * checkouts or do not depend on activities that
     * have checkouts. This policy overrides DELIVER_NCO_DEVSTR 
     * Not applicable for single stream development
     */
    DELIVER_NCO_SELACT,
    
    /**
     * Allows a rebase operation on the target stream while some 
     * of the files remain checked out in the view.
     * Not applicable for single stream development
     */
    REBASE_CO,
    
    /**
     * Allow a deliver operation from a stream in the same project 
     * to include changes from the stream's foundation baselines
     * Not applicable for single stream development
     */
    INTRAPROJECT_DELIVER_FOUNDATION_CHANGES,
    
    /**
     * Allow a deliver operation from a stream in the same project to
     * contain changes in components that are not included in the target
     * stream's configuration
     * Not applicable for single stream development
     */
    INTRAPROJECT_DELIVER_ALLOW_MISSING_TGTCOMPS,
    
    /**
     * Allow streams in this project to accept changes in a deliver 
     * operation from a stream in a different project.
     */
    INTERPROJECT_DELIVER,
    
    /**
     * Allow a deliver operation from a stream in a different project to
     * include changes from the stream's foundation baselines. 
     */
    INTERPROJECT_DELIVER_FOUNDATION_CHANGES,
    
    /**
     * Require a deliver operation from a stream in a different project to 
     * deliver changes in all components
     */
    INTERPROJECT_DELIVER_REQUIRE_TGTCOMP_VISIBILITY,
    
    /**
     * Allow a deliver operation from a stream in a different project to contain 
     * changes in components that are not modifiable in the target stream's configuration
     */
    INTERPROJECT_DELIVER_ALLOW_NONMOD_TGTCOMPS    
};
